@@ -31,6 +31,12 @@ class User(BaseModel):
     external_url: Optional[str]
     is_business: bool
 
+    public_email: Optional[str]
+    contact_phone_number: Optional[str]
+    business_contact_method: Optional[str]
+    business_category_name: Optional[str]
+    category_name: Optional[str]
+
     _external_url = validator('external_url', allow_reuse=True)(validate_external_url)
 
 
